@@ -6,5 +6,6 @@ from . import nebula
 from . import odps
 from . import oss
 from . import resource
+from ..utils import support
 
-__all__ = ['oss', 'odps', 'nebula', 'resource']
+__all__ = ['oss', 'odps', 'nebula', 'resource','support']
