@@ -5,12 +5,21 @@
 import json
 import logging
 import time
+from typing import Dict
+
+import pandas as pd
+import prettytable
+from nebula3.data.DataObject import Value, ValueWrapper
+from nebula3.data.ResultSet import ResultSet
 
 from ..utils import support
 
-__all__ = ['Client', 'print_resp']
+__all__ = ['Client', 'result_to_df', 'print_result', 'print_resp']
 
 
+#####################################
+#           Nebula Client           #
+#####################################
 class Client:
     def __init__(self, nebula_connect=None):
         self.client = nebula_connect or support.nebula_connect()
@@ -30,7 +39,7 @@ class Client:
         json_obj = json.loads(resp_json)
         return json.dumps(json_obj, indent=1, sort_keys=True)
 
-    def create_space(self, space: str = '', comment: str = '', vid_str_fixed_size: int = 50):
+    def create_space(self, space: str = '', comment: str = '', vid_str_fixed_size: int = 0):
         space = space or self.space
         comment = comment or self.comment
         vid_str_fixed_size = vid_str_fixed_size or self.vid_str_fixed_size
@@ -89,50 +98,66 @@ class Client:
         self.exec_query(query, self.heart_beat)
 
 
-import prettytable
+#####################################
+#   Scan Method 1 (Recommended)     #
+#####################################
+def result_to_df(result: ResultSet) -> pd.DataFrame:
+    """
+    build list for each column, and transform to dataframe
+    """
+    assert result.is_succeeded()
+    columns = result.keys()
+    d: Dict[str, list] = {}
+    for col_num in range(result.col_size()):
+        col_name = columns[col_num]
+        col_list = result.column_values(col_name)
+        d[col_name] = [x.cast() for x in col_list]
+    return pd.DataFrame.from_dict(d, columns=columns)
 
 
-def print_resp(resp):
+#####################################
+#   Scan Method 2   (Customize)     #
+#####################################
+cast_as = {
+    Value.NVAL: "as_null",
+    Value.__EMPTY__: "as_empty",
+    Value.BVAL: "as_bool",
+    Value.IVAL: "as_int",
+    Value.FVAL: "as_double",
+    Value.SVAL: "as_string",
+    Value.LVAL: "as_list",
+    Value.UVAL: "as_set",
+    Value.MVAL: "as_map",
+    Value.TVAL: "as_time",
+    Value.DVAL: "as_date",
+    Value.DTVAL: "as_datetime",
+    Value.VVAL: "as_vertex",
+    Value.EVAL: "as_edge",
+    Value.PVAL: "as_path",
+    Value.GGVAL: "as_geography",
+    Value.DUVAL: "as_duration",
+}
+
+
+def customized_cast_with_dict(val: ValueWrapper):
+    _type = val._value.getType()
+    method = cast_as.get(_type)
+    if method is not None:
+        return getattr(val, method, lambda *args, **kwargs: None)()
+    raise KeyError("No such key: {}".format(_type))
+
+
+def print_resp(resp: ResultSet):
     assert resp.is_succeeded()
     output_table = prettytable.PrettyTable()
     output_table.field_names = resp.keys()
     for recode in resp:
         value_list = []
         for col in recode:
-            if col.is_empty():
-                value_list.append('__EMPTY__')
-            elif col.is_null():
-                value_list.append('__NULL__')
-            elif col.is_bool():
-                value_list.append(col.as_bool())
-            elif col.is_int():
-                value_list.append(col.as_int())
-            elif col.is_double():
-                value_list.append(col.as_double())
-            elif col.is_string():
-                value_list.append(col.as_string())
-            elif col.is_time():
-                value_list.append(col.as_time())
-            elif col.is_date():
-                value_list.append(col.as_date())
-            elif col.is_datetime():
-                value_list.append(col.as_datetime())
-            elif col.is_list():
-                value_list.append(col.as_list())
-            elif col.is_set():
-                value_list.append(col.as_set())
-            elif col.is_map():
-                value_list.append(col.as_map())
-            elif col.is_vertex():
-                value_list.append(col.as_node())
-            elif col.is_edge():
-                value_list.append(col.as_relationship())
-            elif col.is_path():
-                value_list.append(col.as_path())
-            elif col.is_geography():
-                value_list.append(col.as_geography())
-            else:
-                print('ERROR: Type unsupported')
-                return
+            val = customized_cast_with_dict(col)
+            value_list.append(val)
         output_table.add_row(value_list)
     print(output_table)
+
+
+print_result = print_resp
