@@ -7,12 +7,12 @@ import shutil
 import time
 
 
-def get_suffix(path):
+def get_suffix(path) -> str:
     """路径后缀"""
     return os.path.splitext(path)[1]
 
 
-def dir2list_with_suffix(dirpath: str, suffix=('.xlsx', '.csv', '.tsv'), ignoring_hidden_file: bool = True):
+def dir2list_with_suffix(dirpath: str, suffix=('.xlsx', '.csv', '.tsv'), ignoring_hidden_file: bool = True) -> list:
     return [os.path.join(dirpath, path) for path in os.listdir(dirpath) if
             get_suffix(path) in suffix and (path[0] != '.' if ignoring_hidden_file else True)]
 
@@ -27,7 +27,7 @@ def makedirs(dirpath: str):
         os.makedirs(dirpath)
 
 
-def subdir_list(dirpath, vextract: str = 'all'):
+def subdir_list(dirpath, vextract: str = 'all') -> list:
     """获取目录下所有子目录名
     @param dirname: str 目录路径
     @param vextract: str file、dir、all（获取文件/目录/所有）
@@ -78,7 +78,7 @@ def move_dir(src_path, dst_path):
         shutil.move(src, dst)
 
 
-def dir_size(path: str):
+def dir_size(path: str) -> int:
     """
     文件夹大小
 
@@ -90,23 +90,23 @@ def dir_size(path: str):
         return size
 
 
-def parse_filepath(filepath):
+def parse_filepath(filepath) -> tuple:
     filepath, fullflname = os.path.split(filepath)
     fname, ext = os.path.splitext(fullflname)
     return filepath, fname, ext
 
 
-def get_modify_time(file: str, format: str = '%Y/%m/%d %H:%M:%S'):
+def get_modify_time(file: str, format: str = '%Y/%m/%d %H:%M:%S') -> str:
     """文件名的后四位（是日期）"""
     return time.strftime(format, time.localtime(os.stat(file).st_mtime))
 
 
-def get_create_time(file: str, format: str = '%Y/%m/%d %H:%M:%S'):
+def get_create_time(file: str, format: str = '%Y/%m/%d %H:%M:%S') -> str:
     """文件名的后四位（是日期）"""
     return time.strftime(format, time.localtime(os.stat(file).st_ctime))
 
 
-def network_state():
+def network_state() -> bool:
     '''ping 网络状态'''
     logging.info('Check Network...')
     result = os.system(u"ping -c2 baidu.com > /dev/null 2>&1")  # 都丢弃，防止输出到控制台
